==> haskell-libxml-sax-0.7.6-68-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libxml-sax
version:                0.7.6
visibility:             public
id:                     libxml-sax-0.7.6-8CtVHzYnk2K4z3uPvYOfeT
key:                    libxml-sax-0.7.6-8CtVHzYnk2K4z3uPvYOfeT
license:                MIT
maintainer:             jmillikin@gmail.com
author:                 John Millikin
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-libxml-sax
synopsis:               Bindings for the libXML2 SAX interface
category:               Foreign, Text, XML, Parsing
abi:                    d2910333e2468f58637266720bb09c73
exposed:                True
exposed-modules:        Text.XML.LibXML.SAX
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libxml-sax
hs-libraries:           HSlibxml-sax-0.7.6-8CtVHzYnk2K4z3uPvYOfeT
extra-libraries:        xml2 xml2
extra-libraries-static: xml2 m z lzma pthread icuuc icudata pthread m
include-dirs:           /usr/include/libxml2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:     /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:           /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-sax-0.7.6-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml-sax.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libxml-sax
version:                0.7.6
visibility:             public
id:                     libxml-sax-0.7.6-HG0qiXmXuwK17XuQdhyktf
key:                    libxml-sax-0.7.6-HG0qiXmXuwK17XuQdhyktf
license:                MIT
maintainer:             jmillikin@gmail.com
author:                 John Millikin
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-libxml-sax
synopsis:               Bindings for the libXML2 SAX interface
category:               Foreign, Text, XML, Parsing
abi:                    545b672747a4bb5ddaa0b2612fd3ee76
exposed:                True
exposed-modules:        Text.XML.LibXML.SAX
import-dirs:            /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs:           /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
library-dirs-static:    /usr/lib/ghc-9.4.8/site-local/libxml-sax-0.7.6
dynamic-library-dirs:   /usr/lib
data-dir:               /usr/share/haskell-libxml-sax
hs-libraries:           HSlibxml-sax-0.7.6-HG0qiXmXuwK17XuQdhyktf
extra-libraries:        xml2 xml2
extra-libraries-static: xml2 m z lzma pthread icuuc icudata pthread m
include-dirs:           /usr/include/libxml2
depends:
    base-4.17.2.1 bytestring-0.11.5.3 text-2.0.2
    xml-types-0.3.8-IpGyuvvNOu2AH1SOobl25

haddock-interfaces:     /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:           /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
